@@ -610,6 +610,95 @@ void cbdatumsetsize(CBDATUM *datum, int size){
 }
 
 
+/* Perform formatted output into a datum. */
+void cbdatumprintf(CBDATUM *datum, const char *format, ...){
+  va_list ap;
+  char *tmp, cbuf[CB_NUMBUFSIZ], tbuf[CB_NUMBUFSIZ*2];
+  unsigned char c;
+  int cblen, tlen;
+  assert(datum && format);
+  va_start(ap, format);
+  while(*format != '\0'){
+    if(*format == '%'){
+      cbuf[0] = '%';
+      cblen = 1;
+      format++;
+      while(strchr("0123456789 .+-", *format) && *format != '\0' && cblen < CB_NUMBUFSIZ - 1){
+        cbuf[cblen++] = *format;
+        format++;
+      }
+      cbuf[cblen++] = *format;
+      cbuf[cblen] = '\0';
+      switch(*format){
+      case 's':
+        tmp = va_arg(ap, char *);
+        if(!tmp) tmp = "(null)";
+        cbdatumcat(datum, tmp, -1);
+        break;
+      case 'd':
+        tlen = sprintf(tbuf, cbuf, va_arg(ap, int));
+        cbdatumcat(datum, tbuf, tlen);
+        break;
+      case 'o': case 'u': case 'x': case 'X': case 'c':
+        tlen = sprintf(tbuf, cbuf, va_arg(ap, unsigned int));
+        cbdatumcat(datum, tbuf, tlen);
+        break;
+      case 'e': case 'E': case 'f': case 'g': case 'G':
+        tlen = sprintf(tbuf, cbuf, va_arg(ap, double));
+        cbdatumcat(datum, tbuf, tlen);
+        break;
+      case '@':
+        tmp = va_arg(ap, char *);
+        if(!tmp) tmp = "(null)";
+        while(*tmp){
+          switch(*tmp){
+          case '&': cbdatumcat(datum, "&amp;", 5); break;
+          case '<': cbdatumcat(datum, "&lt;", 4); break;
+          case '>': cbdatumcat(datum, "&gt;", 4); break;
+          case '"': cbdatumcat(datum, "&quot;", 6); break;
+          default:
+            if(!((*tmp >= 0 && *tmp <= 0x8) || (*tmp >= 0x0e && *tmp <= 0x1f)))
+              cbdatumcat(datum, tmp, 1);
+            break;
+          }
+          tmp++;
+        }
+        break;
+      case '?':
+        tmp = va_arg(ap, char *);
+        if(!tmp) tmp = "(null)";
+        while(*tmp){
+          c = *(unsigned char *)tmp;
+          if((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') ||
+             (c >= '0' && c <= '9') || (c != '\0' && strchr("_-.", c))){
+            cbdatumcat(datum, tmp, 1);
+          } else {
+            tlen = sprintf(tbuf, "%%%02X", c);
+            cbdatumcat(datum, tbuf, tlen);
+          }
+          tmp++;
+        }
+        break;
+      case ':':
+        tmp = va_arg(ap, char *);
+        if(!tmp) tmp = "";
+        tmp = cbmimeencode(tmp, "UTF-8", TRUE);
+        cbdatumcat(datum, tmp, -1);
+        free(tmp);
+        break;
+      case '%':
+        cbdatumcat(datum, "%", 1);
+        break;
+      }
+    } else {
+      cbdatumcat(datum, format, 1);
+    }
+    format++;
+  }
+  va_end(ap);
+}
+
+
 /* Convert a datum to an allocated region. */
 char *cbdatumtomalloc(CBDATUM *datum, int *sp){
   char *ptr;
