@@ -671,6 +671,8 @@ int domisc(void){
     memcpy(tmp, "123", 3);
     cbdatumsetbuf(ndatum, tmp, 3);
   }
+  cbdatumprintf(ndatum, "[%s\t%08d\t%08o\t%08x\t%08.1f\t%@\t%?\t%:]",
+                "mikio", 1978, 1978, 1978, 1978.0211, "<>&#!+-*/%", "<>&#!+-*/%", "<>&#!+-*/%");
   cbdatumclose(ndatum);
   cbdatumclose(odatum);
   printfflush("ok\n");
