@@ -791,7 +791,10 @@ int dpoptimize(DEPOT *depot, int bnum){
     return FALSE;
   }
   sprintf(name, "%s%s", depot->name, DP_TMPFSUF);
-  bnum = dpgetprime(bnum > 0 ? bnum : (int)(depot->rnum * (1.0 / DP_OPTBLOAD)) + 1);
+  if(bnum < 0){
+    bnum = (int)(depot->rnum * (1.0 / DP_OPTBLOAD)) + 1;
+    if(bnum < DP_DEFBNUM / 2) bnum = DP_DEFBNUM / 2;
+  }
   if(!(tdepot = dpopen(name, DP_OWRITER | DP_OCREAT | DP_OTRUNC, bnum))){
     free(name);
     depot->fatal = TRUE;
